=head1

Locale::CLDR::Locales::Ak::Any::Gh - Package for language Akan

=cut

package Locale::CLDR::Locales::Ak::Any::Gh;
# This file auto generated from Data\common\main\ak_GH.xml
#	on Fri 13 Apr  7:00:47 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.32.0');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

extends('Locale::CLDR::Locales::Ak::Any');
no Moo;

1;

# vim: tabstop=4
